@@ -1,8 +1,7 @@
 require 'spec_helper'
 
 describe 'cinder::api' do
-
-  shared_examples_for 'cinder api' do
+  shared_examples 'cinder api' do
     let :pre_condition do
       "class { '::cinder::keystone::authtoken':
          password => 'foo',
@@ -13,7 +12,7 @@ describe 'cinder::api' do
       {}
     end
 
-    describe 'with only required params' do
+    context 'with only required params' do
       let :params do
         req_params
       end
@@ -31,9 +30,6 @@ describe 'cinder::api' do
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_workers').with(
          :value => '8'
         )
-        is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with(
-         :value => 'compute:Compute Service:publicURL'
-        )
         is_expected.to contain_cinder_config('DEFAULT/default_volume_type').with(
          :value => '<SERVICE DEFAULT>'
         )
@@ -53,30 +49,18 @@ describe 'cinder::api' do
          :value => 'keystone'
         )
 
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('key_manager/backend').with_value('cinder.keymgr.conf_key_mgr.ConfKeyManager')
         is_expected.to contain_cinder_config('barbican/barbican_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('barbican/auth_endpoint').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/osapi_volume_listen_port').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_oslo__middleware('cinder_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+          :max_request_body_size        => '<SERVICE DEFAULT>',
         )
       end
     end
 
-    describe 'with a custom nova_catalog params' do
-      let :params do
-        req_params.merge({
-          'nova_catalog_info'       => 'compute:nova:publicURL',
-        })
-      end
-      it { is_expected.to contain_cinder_config('DEFAULT/nova_catalog_info').with_value('compute:nova:publicURL') }
-    end
-
-    describe 'with a custom region for nova' do
+    context 'with a custom region for nova' do
       let :params do
         req_params.merge({'os_region_name' => 'MyRegion'})
       end
@@ -87,7 +71,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with a customized port' do
+    context 'with a customized port' do
       let :params do
         req_params.merge({'osapi_volume_listen_port' => 9999})
       end
@@ -98,76 +82,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with an OpenStack privileged account' do
-
-      context 'with all needed params' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-            'os_privileged_user_tenant'   => 'admin',
-            'os_privileged_user_auth_url' => 'http://localhost:8080',
-          })
-        end
-
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('password') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('http://localhost:8080') }
-      end
-
-      context 'without os_privileged_user_auth_url' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-            'os_privileged_user_tenant'   => 'admin',
-          })
-        end
-
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_name').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_password').with_value('password') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_tenant').with_value('admin') }
-        it { is_expected.to contain_cinder_config('DEFAULT/os_privileged_user_auth_url').with_value('<SERVICE DEFAULT>') }
-      end
-
-      context 'without os_privileged_user' do
-        let :params do
-          req_params.merge({
-            'privileged_user' => 'true',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_name parameter is required when privileged_user is set to true/
-      end
-
-      context 'without os_privileged_user_password' do
-        let :params do
-          req_params.merge({
-            'privileged_user'         => 'true',
-            'os_privileged_user_name' => 'admin',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_password parameter is required when privileged_user is set to true/
-      end
-
-      context 'without os_privileged_user_tenant' do
-        let :params do
-          req_params.merge({
-            'privileged_user'             => 'true',
-            'os_privileged_user_name'     => 'admin',
-            'os_privileged_user_password' => 'password',
-          })
-        end
-
-        it_raises 'a Puppet::Error', /The os_privileged_user_tenant parameter is required when privileged_user is set to true/
-      end
-    end
-
-    describe 'with a default volume type' do
+    context 'with a default volume type' do
       let :params do
         req_params.merge({'default_volume_type' => 'foo'})
       end
@@ -178,7 +93,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with only required params' do
+    context 'with only required params' do
       let :params do
         req_params.merge({'bind_host' => '192.168.1.3'})
       end
@@ -189,7 +104,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with sync_db set to false' do
+    context 'with sync_db set to false' do
       let :params do
         {
           :enabled => true,
@@ -199,7 +114,7 @@ describe 'cinder::api' do
       it { is_expected.not_to contain_class('cinder::db::sync') }
     end
 
-    describe 'with enabled false' do
+    context 'with enabled false' do
       let :params do
         req_params.merge({'enabled' => false})
       end
@@ -211,7 +126,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with manage_service false' do
+    context 'with manage_service false' do
       let :params do
         req_params.merge({'manage_service' => false})
       end
@@ -223,7 +138,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with ratelimits' do
+    context 'with ratelimits' do
       let :params do
         req_params.merge({ :ratelimits => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)' })
       end
@@ -233,7 +148,7 @@ describe 'cinder::api' do
       )}
     end
 
-    describe 'with encryption_auth_url' do
+    context 'with encryption_auth_url' do
       let :params do
         req_params.merge({ :keymgr_encryption_auth_url => 'http://localhost:5000/v3' })
       end
@@ -243,7 +158,7 @@ describe 'cinder::api' do
       )}
     end
 
-    describe 'while validating the service with default command' do
+    context 'while validating the service with default command' do
       let :params do
         req_params.merge({
           :validate => true,
@@ -255,7 +170,7 @@ describe 'cinder::api' do
       )}
     end
 
-    describe 'with a custom auth_strategy' do
+    context 'with a custom auth_strategy' do
       let :params do
         req_params.merge({'auth_strategy' => 'noauth'})
       end
@@ -266,7 +181,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with a custom osapi_max_limit' do
+    context 'with a custom osapi_max_limit' do
       let :params do
         req_params.merge({'osapi_max_limit' => '10000'})
       end
@@ -276,7 +191,7 @@ describe 'cinder::api' do
         )
       end
     end
-    describe 'when running cinder-api in wsgi' do
+    context 'when running cinder-api in wsgi' do
       let :params do
         req_params.merge!({ :service_name => 'httpd' })
       end
@@ -298,7 +213,7 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'when service_name is not valid' do
+    context 'when service_name is not valid' do
       let :params do
         req_params.merge!({ :service_name => 'foobar' })
       end
@@ -314,7 +229,7 @@ describe 'cinder::api' do
       it_raises 'a Puppet::Error', /Invalid service_name/
     end
 
-    describe 'with SSL socket options set' do
+    context 'with SSL socket options set' do
       let :params do
         req_params.merge!({
           :use_ssl   => true,
@@ -329,7 +244,7 @@ describe 'cinder::api' do
       it { is_expected.to contain_cinder_config('ssl/key_file').with_value('/path/to/key') }
     end
 
-    describe 'with SSL socket options set wrongly configured' do
+    context 'with SSL socket options set wrongly configured' do
       let :params do
         req_params.merge!({
           :use_ssl  => true,
@@ -341,7 +256,7 @@ describe 'cinder::api' do
       it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
     end
 
-    describe 'with barbican parameters' do
+    context 'with barbican parameters' do
       let :params do
         req_params.merge!({
           :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
@@ -356,17 +271,6 @@ describe 'cinder::api' do
       end
     end
 
-    describe 'with barbican deprecated parameters' do
-      let :params do
-        req_params.merge!({
-          :keymgr_api_class           => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-        })
-      end
-      it 'should set keymgr parameter' do
-        is_expected.to contain_cinder_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-      end
-    end
-
   end
 
   on_supported_os({
@@ -381,7 +285,7 @@ describe 'cinder::api' do
         }))
       end
 
-      it_configures 'cinder api'
+      it_behaves_like 'cinder api'
     end
   end
 end
