@@ -48,6 +48,7 @@ describe 'cinder::keystone::auth' do
     context 'when overriding parameters' do
       before do
         params.merge!({
+          :roles           => ['admin', 'service'],
           :region          => 'RegionThree',
           :public_url_v2   => 'https://10.0.42.1:4242/v42/%(tenant_id)s',
           :admin_url_v2    => 'https://10.0.42.2:4242/v42/%(tenant_id)s',
@@ -58,6 +59,11 @@ describe 'cinder::keystone::auth' do
         })
       end
 
+      it { is_expected.to contain_keystone_user_role('cinder@services').with(
+        :ensure  => 'present',
+        :roles   => ['admin', 'service']
+      )}
+
       it { is_expected.to contain_keystone_endpoint('RegionThree/cinderv2::volumev2').with(
         :ensure       => 'present',
         :public_url   => 'https://10.0.42.1:4242/v42/%(tenant_id)s',
